@@ -2,37 +2,9 @@ package Module::Build::DAGOLDEN;
 use strict;
 use Module::Build;
 use vars qw/@ISA/;
-BEGIN { @ISA = 'Module::Build' }
-use IO::File;
+@ISA = qw/Module::Build/;
 use File::Spec;
 
-sub ACTION_distdir {
-    my $self = shift;
-    $self->depends_on('wikidoc');
-    $self->SUPER::ACTION_distdir;
-}
-
-sub ACTION_testpod {
-    my $self = shift;
-    $self->depends_on('wikidoc');
-    $self->SUPER::ACTION_testpod;
-}
-
-sub ACTION_test {
-    my $self = shift;
-    my $missing_pod;
-    for my $src ( keys %{ $self->find_pm_files() } ) {
-        next unless _has_pod($src);
-        (my $tgt = $src) =~ s{\.pm$}{.pod};
-        $missing_pod = 1 if ! -e $tgt;
-    }
-    if ( $missing_pod ) {
-        $self->depends_on('wikidoc');
-        $self->depends_on('build');
-    }
-    $self->SUPER::ACTION_test;
-}
-
 sub ACTION_wikidoc {
     my $self = shift;
     eval "use Pod::WikiDoc";
@@ -42,7 +14,6 @@ sub ACTION_wikidoc {
             keywords => { VERSION => $self->dist_version },
         });
         for my $src ( keys %{ $self->find_pm_files() } ) {
-            next unless _has_pod( $src ); 
             (my $tgt = $src) =~ s{\.pm$}{.pod};
             $parser->filter( {
                 input   => $src,
@@ -58,11 +29,36 @@ sub ACTION_wikidoc {
     }
 }
 
-sub _has_pod {
-    my ($file) = shift;
-    my $fh = IO::File->new( $file );
-    my $data = do {local $/; <$fh>};
-    return $data =~ m{^=(?:pod|head\d|over|item|begin)\b}ms;
+sub ACTION_test {
+    my $self = shift;
+    my $missing_pod;
+    for my $src ( keys %{ $self->find_pm_files() } ) {
+        (my $tgt = $src) =~ s{\.pm$}{.pod};
+        $missing_pod = 1 if ! -e $tgt;
+    }
+    if ( $missing_pod ) {
+        $self->depends_on('wikidoc');
+        $self->depends_on('build');
+    }
+    $self->SUPER::ACTION_test;
+}
+
+sub ACTION_testpod {
+    my $self = shift;
+    $self->depends_on('wikidoc');
+    $self->SUPER::ACTION_testpod;
+}
+
+sub ACTION_distmeta {
+    my $self = shift;
+    $self->depends_on('wikidoc');
+    $self->SUPER::ACTION_distmeta;
+}
+
+sub ACTION_distdir {
+    my $self = shift;
+    $self->depends_on('wikidoc');
+    $self->SUPER::ACTION_distdir;
 }
 
 1;
